Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2263)

Unified Diff: chrome/browser/sync/protocol/password_specifics.proto

Issue 2828021: Take 2: sync changes to support encryption (Closed)
Patch Set: fix flaky password test under valgrind Created 10 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/protocol/password_specifics.proto
diff --git a/chrome/browser/sync/protocol/password_specifics.proto b/chrome/browser/sync/protocol/password_specifics.proto
index 4d1bc17ef8e1368b3b4516feb6ad6e1e2a6af6f0..efd3400b181a6c03e1ed4df38292496c1402e57f 100644
--- a/chrome/browser/sync/protocol/password_specifics.proto
+++ b/chrome/browser/sync/protocol/password_specifics.proto
@@ -10,10 +10,11 @@ option optimize_for = LITE_RUNTIME;
package sync_pb;
+import "encryption.proto";
import "sync.proto";
// These are the properties that get serialized into the |blob| field of
// |PasswordSpecifics|.
message PasswordSpecificsData {
optional int32 scheme = 1;
optional string signon_realm = 2;
@@ -29,10 +30,10 @@ message PasswordSpecificsData {
optional bool blacklisted = 12;
}
-// Properties of password sync objects.
+// Properties of password sync objects. The actual password data is held in a
+// PasswordSpecificsData that is encrypted into |encrypted|.
message PasswordSpecifics {
- optional string key = 1;
- optional string blob = 2;
+ optional EncryptedData encrypted = 1;
}
extend EntitySpecifics {
« no previous file with comments | « chrome/browser/sync/profile_sync_service_password_unittest.cc ('k') | chrome/browser/sync/syncable/directory_manager.h » ('j') | no next file with comments »
@@ -10,10 +10,11 @@ option optimize_for = LITE_RUNTIME;
import "sync.proto";
-// These are the properties that get serialized into the |blob| field of
-// |PasswordSpecifics|.
+// These are the properties that get serialized into the |encrypted| field of
+// PasswordSpecifics.
message PasswordSpecificsData {
optional int32 scheme = 1;

Powered by Google App Engine
This is Rietveld 408576698